@@ -1,37 +1,6 @@
-"AR1met" <-
-function (rho = 0.4, p = 5, out = "TOE") 
-{
-    library(ts)
-    if (!length(rho) == 1) {
-        p <- length(rho)
-        rho <- rho - mean(rho)
-        rho <- sum(rho[2:p] * rho[1:(p - 1)])/sum(rho^2)
-    }
-    tridiag <- function(rho, p) {
-        mro <- diag(rep(1, p))
-        mro[1, 2] <- rho
-        mro[p, p - 1] <- rho
-        for (i in 2:(p - 1)) {
-            mro[i, i + 1] <- rho
-            mro[i, i - 1] <- rho
-        }
-        return(mro)
-    }
-    if (out == "TOE") 
-        return(toeplitz(rho^(0:(p - 1))))
-    if (out == "TRI") 
-        return(1/(1 - rho^2) * (tridiag(-rho, p) + diag(c(0, 
-            rep(rho^2, p - 2), 0))))
-    if (out == "K-1") {
-        mm <- tridiag(-rho, p)
-        mm[1, 1] <- sqrt(1 - rho^2)
-        for (i in 1:(p - 1)) mm[i, i + 1] <- 0
-        return(mm)
-    }
-}
 "CauRuimet" <-
-function (Z, ker = 1, m0 = 1, withingroup = TRUE, loc = substitute(apply(Z, 
-    2, mean, trim = 0.1)), matrixmethod = TRUE) 
+function (Z, ker = 1, m0 = 1, withingroup = TRUE, loc = substitute(apply(Z,
+    2, mean, trim = 0.1)), matrixmethod = TRUE)
 {
     debtime <- proc.time()
     if (m0 == "tridiag") {
@@ -60,7 +29,7 @@ function (Z, ker = 1, m0 = 1, withingroup = TRUE, loc = substitute(apply(Z,
         if (matrixmethod) {
             distZiZj <- norm2S(t(Z))
             diadis <- diag(distZiZj)/2
-            distZiZj <- 2 * sweep(sweep(-distZiZj, 2, -diadis), 
+            distZiZj <- 2 * sweep(sweep(-distZiZj, 2, -diadis),
                 1, -diadis)
             M <- m0 * ker(distZiZj)
             sumM <- (sum(as.vector(M)) - dim(Z)[1])/2
@@ -72,9 +41,9 @@ function (Z, ker = 1, m0 = 1, withingroup = TRUE, loc = substitute(apply(Z,
             totad <- 0
             for (i in 1:(dim(Z)[1] - 1)) for (j in (i + 1):dim(Z)[1]) {
                 ad <- as.double(ker(norm2S(Z[i, ] - Z[j, ])))
-                if (is.matrix(m0)) 
+                if (is.matrix(m0))
                   ad <- ad * m0[i, j]
-                W <- W + ad * ((Z[i, ] - Z[j, ]) %o% (Z[i, ] - 
+                W <- W + ad * ((Z[i, ] - Z[j, ]) %o% (Z[i, ] -
                   Z[j, ]))
                 totad <- totad + ad
             }
@@ -88,30 +57,30 @@ function (Z, ker = 1, m0 = 1, withingroup = TRUE, loc = substitute(apply(Z,
         for (i in 1:(dim(Z)[1])) {
             ad <- as.double(ker(norm2S(Z[i, ] - mz)))
             W <- W + ad * ((Z[i, ] - mz) %o% (Z[i, ] - mz))
-            if (is.matrix(m0)) 
+            if (is.matrix(m0))
                 ad <- ad * m0[i, j]
             totad <- totad + ad
         }
         totad <- totad * dim(Z)[1]^2
         W <- W/totad
     }
-    cat("-----Execution Time-----", (proc.time() - debtime)[3], 
+    cat("-----Execution Time-----", (proc.time() - debtime)[3],
         "\n")
     return(W)
 }
 "Detren" <-
-function (dat, Mm = c(1, 3), rsd = TRUE, tren = function(x) smooth.spline(as.vector(x), 
-    df = 5)$y) 
+function (dat, Mm = c(1, 3), rsd = TRUE, tren = function(x) smooth.spline(as.vector(x),
+    df = 5)$y)
 {
     tre <- apply(dat, Mm, FUN = tren)
     dimi <- c(dim(dat)[-Mm], dim(dat)[Mm])
     tre <- aperm(array(tre, dimi), match(dimi, dim(dat)))
-    if (rsd) 
+    if (rsd)
         return(dat - tre)
     else return(tre)
 }
 "FCAmet" <-
-function (X, chi2 = FALSE, E = NULL) 
+function (X, chi2 = FALSE, E = NULL)
 {
     if (!is.array(X)) {
         stop(paste("--- X must be an array  ! ---"))
@@ -129,30 +98,30 @@ function (X, chi2 = FALSE, E = NULL)
         Indep <- array(Indep, dim(X))
         Chi2 <- N * sum((X/N - Indep)^2/Indep)
         cat("\n", " --")
-        cat("\n", "++++ Data is            ", deparse(datanam), 
+        cat("\n", "++++ Data is            ", deparse(datanam),
             "        +++++++")
-        cat("\n", "-------------- Multiple contingency Table of dimensions ", 
+        cat("\n", "-------------- Multiple contingency Table of dimensions ",
             dim(X), "  ----", "\n")
-        cat("\n", "-------------- Chi2 = ", Chi2, " with ddl = ", 
+        cat("\n", "-------------- Chi2 = ", Chi2, " with ddl = ",
             prod(dim(X) - 1))
-        cat("\n", " ------------- p(>Chi2)= ", pchisq(Chi2, df = prod(dim(X) - 
+        cat("\n", " ------------- p(>Chi2)= ", pchisq(Chi2, df = prod(dim(X) -
             1), lower.tail = FALSE), "\n")
         cat("\n", " --", "\n")
     }
-    if (!is.null(E)) 
-        invisible(list(data = (X/N - E)/Indep, met = metafc, 
+    if (!is.null(E))
+        invisible(list(data = (X/N - E)/Indep, met = metafc,
             count = N))
     else invisible(list(data = (X/N)/Indep, met = metafc, count = N))
 }
 "Ginv" <-
-function (A) 
+function (A)
 {
     Powmat(A, -1)
 }
 "IterMV" <-
-function (n = 10, dat = J12.dat, Mm = c(1, 3), Vm = c(2, 3), 
-    fFUN = mean, usetren = FALSE, tren = function(x) smooth.spline(as.vector(x), 
-        df = 5)$y, rsd = TRUE) 
+function (n = 10, dat = J12.dat, Mm = c(1, 3), Vm = c(2, 3),
+    fFUN = mean, usetren = FALSE, tren = function(x) smooth.spline(as.vector(x),
+        df = 5)$y, rsd = TRUE)
 {
     sdev <- function(x) {
         sd(as.vector(x))
@@ -166,18 +135,18 @@ function (n = 10, dat = J12.dat, Mm = c(1, 3), Vm = c(2, 3),
             dat <- sweep(dat, Mm, mean.dat)
         }
         sd.dat <- apply(dat, Vm, sdev)
-        if (sd.dat == 1) 
+        if (sd.dat == 1)
             warning("zero variances were replaced by 1")
         sd.dat <- ifelse(sd.dat == 0, 1, sd.dat)
         dat <- sweep(dat, Vm, sd.dat, FUN = "/")
     }
-    cat("\n", "---Max of the means: ", max(apply(dat, Mm, mean), 
+    cat("\n", "---Max of the means: ", max(apply(dat, Mm, mean),
         nam = TRUE), "\n")
     return(dat)
 }
 "Multcent" <-
-function (dat = J12.dat, bi = c(1, 2), by = 3, centre = mean, 
-    centrebyBA = c(TRUE, FALSE), scalebyBA = c(TRUE, FALSE)) 
+function (dat = J12.dat, bi = c(1, 2), by = 3, centre = mean,
+    centrebyBA = c(TRUE, FALSE), scalebyBA = c(TRUE, FALSE))
 {
     if (centrebyBA[1]) {
         me <- apply(dat, by, FUN = centre)
@@ -188,7 +157,7 @@ function (dat = J12.dat, bi = c(1, 2), by = 3, centre = mean,
     }
     if (scalebyBA[1]) {
         sca <- apply(dat, by, sdev)
-        if (sca == 1) 
+        if (sca == 1)
             warning("zero variances were replaced by 1")
         sca <- ifelse(sca == 0, 1, sca)
         dat <- sweep(dat, by, sca, FUN = "/")
@@ -205,7 +174,7 @@ function (dat = J12.dat, bi = c(1, 2), by = 3, centre = mean,
     }
     if (scalebyBA[2]) {
         sca <- apply(dat, by, sdev)
-        if (sca == 1) 
+        if (sca == 1)
             warning("zero variances were replaced by 1")
         sca <- ifelse(sca == 0, 1, sca)
         dat <- sweep(dat, by, sca, FUN = "/")
@@ -213,7 +182,7 @@ function (dat = J12.dat, bi = c(1, 2), by = 3, centre = mean,
     return(dat)
 }
 "Powmat" <-
-function (A, pw, eltw = FALSE) 
+function (A, pw, eltw = FALSE)
 {
     A <- as.matrix(A)
     if (eltw) {
@@ -221,7 +190,7 @@ function (A, pw, eltw = FALSE)
         A <- as.vector(A)
         RR <- A^pw
         RR[abs(RR) == Inf] <- A[abs(RR) == Inf]
-        if (dimA[2] > 1) 
+        if (dimA[2] > 1)
             RR <- matrix(RR, ncol = dimA[2])
     }
     else {
@@ -232,35 +201,35 @@ function (A, pw, eltw = FALSE)
             RR <- matrix(0, ncol(A), nrow(A))
             return(RR)
         }
-        if (length(diago) == 1) 
-            RR <- t(as.matrix(valsin$v[, 1]) %*% t(as.matrix(valsin$u[, 
+        if (length(diago) == 1)
+            RR <- t(as.matrix(valsin$v[, 1]) %*% t(as.matrix(valsin$u[,
                 1]))) * diago
-        else RR <- valsin$u[, 1:length(diago)] %*% diag(diago) %*% 
+        else RR <- valsin$u[, 1:length(diago)] %*% diag(diago) %*%
             t(valsin$v[, 1:length(diago)])
         RR <- as.matrix(RR)
-        if (pw < 0 & (!min(dim(RR)) == 1)) 
+        if (pw < 0 & (!min(dim(RR)) == 1))
             RR <- t(RR)
-        if (length(RR) == 1) 
+        if (length(RR) == 1)
             RR <- as.numeric(RR)
-        else if (dim(RR)[1] == 1) 
+        else if (dim(RR)[1] == 1)
             RR <- as.vector(RR)
     }
     return(RR)
 }
 "RaoProd" <-
-function (A, B) 
+function (A, B)
 {
     A <- as.matrix(A)
     B <- as.matrix(B)
-    if (min(dim(A)) == 1 & min(dim(B)) == 1) 
+    if (min(dim(A)) == 1 & min(dim(B)) == 1)
         return(as.vector(A) %x% as.vector(B))
     else {
         if (length(A) == 1 || length(B) == 1) {
-            ifelse(length(B) == 1, return(A * as.vector(B)), 
+            ifelse(length(B) == 1, return(A * as.vector(B)),
                 return(as.vector(A) * B))
         }
         else {
-            if (!dim(A)[2] == dim(B)[2]) 
+            if (!dim(A)[2] == dim(B)[2])
                 stop("Wrong number of columns")
             f <- dim(A)[2]
             re <- array(0, c(dim(A)[1] * dim(B)[1], f))
@@ -272,84 +241,84 @@ function (A, B)
     }
 }
 "RiskJack.plot" <-
-function (solution, nbvs = 1:20, mod = NULL, max = NULL, rescaled = TRUE, 
-    ...) 
+function (solution, nbvs = 1:20, mod = NULL, max = NULL, rescaled = TRUE,
+    ...)
 {
     qchoix <- nbvs
     ord <- length(solution)
-    if (is.null(max)) 
+    if (is.null(max))
         max <- length(solution[[ord]]$d)
-    if (is.null(mod)) 
+    if (is.null(mod))
         mod <- 1:length(solution)
-    val <- solution[[ord]]$d[!substr(solution[[ord]]$vsnam, 1, 
+    val <- solution[[ord]]$d[!substr(solution[[ord]]$vsnam, 1,
         1) == "*"]
-    if (ord > 2) 
+    if (ord > 2)
         iden <- order(val)[length(val):1]
     else iden <- 1:max
     covalid <- function() {
-        mindiff <- min((val[iden][-length(solution[[ord]]$d)]^2 - 
+        mindiff <- min((val[iden][-length(solution[[ord]]$d)]^2 -
             val[iden][-1]^2))
         for (mode in mod) {
-            if (length(solution[[mode]]$v[1, ]) < solution[[ord]]$ssX[1]^2/mindiff/length(solution[[mode]]$v[1, 
+            if (length(solution[[mode]]$v[1, ]) < solution[[ord]]$ssX[1]^2/mindiff/length(solution[[mode]]$v[1,
                 ]^2)) {
-                cat(" WARNING ..mode ", mode, " ..n= ", length(solution[[mode]]$v[1, 
-                  ]), " validity condition  >", solution[[ord]]$ssX[1]^2/mindiff/length(solution[[mode]]$v[1, 
+                cat(" WARNING ..mode ", mode, " ..n= ", length(solution[[mode]]$v[1,
+                  ]), " validity condition  >", solution[[ord]]$ssX[1]^2/mindiff/length(solution[[mode]]$v[1,
                   ]^2), "\n")
             }
         }
     }
-    RJack <- matrix(rep(0, max(mod) * length(qchoix)), c(max(mod), 
+    RJack <- matrix(rep(0, max(mod) * length(qchoix)), c(max(mod),
         length(qchoix)))
     for (m in mod) {
         for (q in qchoix) {
             tl <- 0
-            if (q > (max - 1)) 
+            if (q > (max - 1))
                 q <- max - 1
             for (k in 1:q) {
                 for (j in (q + 1):max(iden)) {
                   l1 <- solution[[ord]]$d[iden[j]]^2
                   l2 <- solution[[ord]]$d[iden[k]]^2
-                  tjk <- mean(solution[[m]]$v[iden[j], ]^2 * 
+                  tjk <- mean(solution[[m]]$v[iden[j], ]^2 *
                     solution[[m]]$v[iden[k], ]^2) * l1 * l2
                   diff <- (l1 - l2)^2
                   tl <- tl + tjk/diff
                 }
             }
-            RJack[m, match(q, qchoix)] <- tl * 1/(length(solution[[m]]$v[j, 
+            RJack[m, match(q, qchoix)] <- tl * 1/(length(solution[[m]]$v[j,
                 ]) - 1)
-            if (q == (max - 1)) 
+            if (q == (max - 1))
                 q <- max(qchoix)
         }
     }
     for (u in mod) {
-        if (rescaled) 
-            RJack[u, ] <- (RJack[u, ] - min(RJack[u, ]))/(max(RJack[u, 
+        if (rescaled)
+            RJack[u, ] <- (RJack[u, ] - min(RJack[u, ]))/(max(RJack[u,
                 ]) - min(RJack[u, ]))
-        plot(qchoix, RJack[u, ], xlab = "Nb of dimensions", ylab = "Risk's approx", 
+        plot(qchoix, RJack[u, ], xlab = "Nb of dimensions", ylab = "Risk's approx",
             lty = u, col = u, type = "b", ...)
         par(new = TRUE)
     }
-    legend(max(qchoix) - 1.5, max(RJack)/2, paste("Risk-mode", 
+    legend(max(qchoix) - 1.5, max(RJack)/2, paste("Risk-mode",
         mod), col = mod, lty = mod, bty = "n", cex = 0.7)
     invisible(par(new = FALSE))
 }
 "Susan1D" <-
-function (y, x = NULL, sigmak = NULL, sigmat = NULL, ker = list(function(u) return(exp(-0.5 * 
-    u^2)))) 
+function (y, x = NULL, sigmak = NULL, sigmat = NULL, ker = list(function(u) return(exp(-0.5 *
+    u^2))))
 {
-    if (is.null(x)) 
+    if (is.null(x))
         x <- 1:length(y)
     else {
-        if (!length(x) == length(y)) 
+        if (!length(x) == length(y))
             stop("Wrong length for x")
         y <- y[order(x)]
         x <- sort(x)
     }
-    if (is.null(sigmat)) 
+    if (is.null(sigmat))
         sigmat <- 8 * (length(y)^(-1/5))
-    if (is.null(sigmak)) 
+    if (is.null(sigmak))
         sigmak <- 1/2 * (range(y)[2] - range(y)[1])
-    if (length(ker) < 2) 
+    if (length(ker) < 2)
         ker <- list(t = ker[[1]], k = ker[[1]])
     knei <- max(1, round(2 * sigmat))
     resul <- y
@@ -357,7 +326,7 @@ function (y, x = NULL, sigmak = NULL, sigmat = NULL, ker = list(function(u) retu
         xt <- 0
         wjt <- 0
         for (j in max(1, t - knei):min(length(y), t + knei)) {
-            wj <- ker$t((x[j] - x[t])/sigmat) * ker$k((y[j] - 
+            wj <- ker$t((x[j] - x[t])/sigmat) * ker$k((y[j] -
                 y[t])/sigmak)
             xt <- xt + wj * y[j]
             wjt <- wjt + wj
@@ -367,27 +336,27 @@ function (y, x = NULL, sigmak = NULL, sigmat = NULL, ker = list(function(u) retu
     return(resul)
 }
 "plot.solutions.PTAk" <-
-function (solution, labels = TRUE, mod = 1, nb1 = 1, nb2 = NULL, 
-    coefi = list(NULL, NULL), xylab = TRUE, ppch = (1:length(solution)), 
-    lengthlabels = 2, ylimit = NULL, scree = FALSE, ordered = TRUE, 
-    nbvs = 40, RiskJack = NULL, method = "", ...) 
+function (solution, labels = TRUE, mod = 1, nb1 = 1, nb2 = NULL,
+    coefi = list(NULL, NULL), xylab = TRUE, ppch = (1:length(solution)),
+    lengthlabels = 2, ylimit = NULL, scree = FALSE, ordered = TRUE,
+    nbvs = 40, RiskJack = NULL, method = "", ...)
 {
-    if (is.null(coefi[[1]])) 
+    if (is.null(coefi[[1]]))
         coefi[[1]] <- rep(1, length(solution))
-    if (is.null(coefi[[2]])) 
+    if (is.null(coefi[[2]]))
         coefi[[2]] <- rep(1, length(solution))
-    if (is.null(lengthlabels)) 
+    if (is.null(lengthlabels))
         lengthlabels <- rep(10, length(solution))
-    if (length(lengthlabels) == 1) 
+    if (length(lengthlabels) == 1)
         lengthlabels <- rep(lengthlabels, length(solution))
     ord <- length(solution)
-    if (as.character(solution[[ord]]$method)[1] == "FCA" | method == 
+    if (as.character(solution[[ord]]$method)[1] == "FCA" | method ==
         "FCA") {
         divv <- solution[[ord]]$ssX[1] - 1
         perclab <- "% FCA"
-        if (length(nbvs) == 1) 
+        if (length(nbvs) == 1)
             nbvs <- 2:nbvs
-        else if (1 %in% nbvs) 
+        else if (1 %in% nbvs)
             nbvs <- nbvs[-match(1, nbvs)]
     }
     else {
@@ -395,7 +364,7 @@ function (solution, labels = TRUE, mod = 1, nb1 = 1, nb2 = NULL,
         perclab <- "% global"
     }
     di <- NULL
-    for (r in 1:length(solution)) di <- c(di, length(solution[[r]]$v[1, 
+    for (r in 1:length(solution)) di <- c(di, length(solution[[r]]$v[1,
         ]))
     if (!scree) {
         ylim <- ylimit
@@ -403,26 +372,26 @@ function (solution, labels = TRUE, mod = 1, nb1 = 1, nb2 = NULL,
         ylab <- ""
         if (is.null(nb2)) {
             xlim <- c(1, max(di[mod]) + 1)
-            if (xylab) 
-                ylab <- paste(solution[[ord]]$vsnam[nb1], " local", 
-                  round(solution[[ord]]$pct[nb1], 2), "% ", round((100 * 
+            if (xylab)
+                ylab <- paste(solution[[ord]]$vsnam[nb1], " local",
+                  round(solution[[ord]]$pct[nb1], 2), "% ", round((100 *
                     (solution[[ord]]$d[nb1])^2)/divv, 2), perclab)
         }
         else {
-            if (xylab) 
-                xlab <- paste(solution[[ord]]$vsnam[nb1], " local", 
-                  round(solution[[ord]]$pct[nb1], 2), "% ", round((100 * 
+            if (xylab)
+                xlab <- paste(solution[[ord]]$vsnam[nb1], " local",
+                  round(solution[[ord]]$pct[nb1], 2), "% ", round((100 *
                     (solution[[ord]]$d[nb1])^2)/divv, 2), perclab)
-            if (xylab) 
-                ylab <- paste(solution[[ord]]$vsnam[nb2], " local", 
-                  round(solution[[ord]]$pct[nb2], 2), "% ", round((100 * 
+            if (xylab)
+                ylab <- paste(solution[[ord]]$vsnam[nb2], " local",
+                  round(solution[[ord]]$pct[nb2], 2), "% ", round((100 *
                     (solution[[ord]]$d[nb2])^2)/divv, 2), perclab)
         }
         for (u in mod) {
             if (!is.null(nb2)) {
-                xy <- t(solution[[u]]$v[c(nb1, nb2), ]) %*% diag(c(coefi[[1]][u], 
+                xy <- t(solution[[u]]$v[c(nb1, nb2), ]) %*% diag(c(coefi[[1]][u],
                   coefi[[2]][u]))
-                xyn <- t(solution[[u]]$v[c(nb1, nb2), ]) %*% 
+                xyn <- t(solution[[u]]$v[c(nb1, nb2), ]) %*%
                   diag(c(coefi[[1]][u], coefi[[2]][u]))
                 ylim <- c(min(ylim, xyn), max(ylim, xyn))
             }
@@ -434,9 +403,9 @@ function (solution, labels = TRUE, mod = 1, nb1 = 1, nb2 = NULL,
         }
         for (u in mod) {
             if (!is.null(nb2)) {
-                xy <- t(solution[[u]]$v[c(nb1, nb2), ]) %*% diag(c(coefi[[1]][u], 
+                xy <- t(solution[[u]]$v[c(nb1, nb2), ]) %*% diag(c(coefi[[1]][u],
                   coefi[[2]][u]))
-                xyn <- t(solution[[u]]$v[c(nb1, nb2), ]) %*% 
+                xyn <- t(solution[[u]]$v[c(nb1, nb2), ]) %*%
                   diag(c(coefi[[1]][u], coefi[[2]][u]))
                 ylim <- c(min(ylim, xyn), max(ylim, xyn))
                 xlim <- ylim
@@ -446,61 +415,61 @@ function (solution, labels = TRUE, mod = 1, nb1 = 1, nb2 = NULL,
                 xy <- solution[[u]]$v[nb1, ] * coefi[[1]][u]
                 xyn <- solution[[u]]$v[nb1, ] * coefi[[1]][u]
                 ylim <- c(min(ylim, xyn), max(ylim, xyn))
-                if (!"xaxt" %in% names(list(...))) 
+                if (!"xaxt" %in% names(list(...)))
                   xaxt <- "n"
             }
             if (labels) {
                 if ("xlab" %in% names(list(...))) {
-                  if ("ylab" %in% names(list(...))) 
-                    plot(xy, xlim = xlim, ylim = ylim, pch = ppch[u], 
+                  if ("ylab" %in% names(list(...)))
+                    plot(xy, xlim = xlim, ylim = ylim, pch = ppch[u],
                       xaxt = xaxt, ...)
-                  else plot(xy, xlim = xlim, ylim = ylim, ylab = ylab, 
+                  else plot(xy, xlim = xlim, ylim = ylim, ylab = ylab,
                     pch = ppch[u], xaxt = xaxt, ...)
-                  if (is.null(nb2)) 
+                  if (is.null(nb2))
                     axis(1, 1:length(xy))
                 }
                 else {
-                  if ("ylab" %in% names(list(...))) 
-                    plot(xy, xlim = xlim, ylim = ylim, pch = ppch[u], 
+                  if ("ylab" %in% names(list(...)))
+                    plot(xy, xlim = xlim, ylim = ylim, pch = ppch[u],
                       xaxt = xaxt, xlab = xlab, ...)
-                  else plot(xy, xlim = xlim, ylim = ylim, ylab = ylab, 
-                    pch = ppch[u], xaxt = xaxt, xlab = xlab, 
+                  else plot(xy, xlim = xlim, ylim = ylim, ylab = ylab,
+                    pch = ppch[u], xaxt = xaxt, xlab = xlab,
                     ...)
                 }
                 if (!is.null(solution[[u]]$n)) {
                   if (is.factor(solution[[u]]$n)) {
-                    if ("cex" %in% names(list(...))) 
+                    if ("cex" %in% names(list(...)))
                       cex <- list(...)$cex
                     else cex <- par("cex")
-                    text(xy, labels = substr(levels(solution[[u]]$n)[as.numeric(solution[[u]]$n)], 
-                      1, lengthlabels[u]), col = as.numeric(solution[[u]]$n), 
+                    text(xy, labels = substr(levels(solution[[u]]$n)[as.numeric(solution[[u]]$n)],
+                      1, lengthlabels[u]), col = as.numeric(solution[[u]]$n),
                       pos = 4, cex = cex)
                     if (is.null(nb2)) {
                       par(new = TRUE)
-                      plot(xy ~ solution[[u]]$n, xlab = "", ylab = "", 
+                      plot(xy ~ solution[[u]]$n, xlab = "", ylab = "",
                         ylim = ylim, cex = cex)
                       par(new = FALSE)
                     }
                   }
-                  else text(xy, labels = substr(solution[[u]]$n, 
+                  else text(xy, labels = substr(solution[[u]]$n,
                     1, lengthlabels[u]), col = u, pos = 4)
                 }
             }
             else if ("xlab" %in% names(list(...))) {
-                if ("ylab" %in% names(list(...))) 
-                  plot(xy, xlim = xlim, ylim = ylim, pch = ppch[u], 
+                if ("ylab" %in% names(list(...)))
+                  plot(xy, xlim = xlim, ylim = ylim, pch = ppch[u],
                     col = u, xaxt = xaxt, ...)
-                else plot(xy, xlim = xlim, ylim = ylim, ylab = ylab, 
+                else plot(xy, xlim = xlim, ylim = ylim, ylab = ylab,
                   pch = ppch[u], col = u, xaxt = xaxt, ...)
-                if (is.null(nb2)) 
+                if (is.null(nb2))
                   axis(1, 1:length(xy))
             }
             else {
-                if ("ylab" %in% names(list(...))) 
-                  plot(xy, xlim = xlim, ylim = ylim, pch = ppch[u], 
+                if ("ylab" %in% names(list(...)))
+                  plot(xy, xlim = xlim, ylim = ylim, pch = ppch[u],
                     col = u, xaxt = xaxt, xlab = xlab, ...)
-                else plot(xy, xlim = xlim, ylim = ylim, ylab = ylab, 
-                  pch = ppch[u], col = u, xaxt = xaxt, xlab = xlab, 
+                else plot(xy, xlim = xlim, ylim = ylim, ylab = ylab,
+                  pch = ppch[u], col = u, xaxt = xaxt, xlab = xlab,
                   ...)
             }
             abline(h = 0, col = "green", lty = 2)
@@ -512,42 +481,42 @@ function (solution, labels = TRUE, mod = 1, nb1 = 1, nb2 = NULL,
     else {
         if (!is.null(ordered)) {
             if (ordered == TRUE) {
-                ld <- length(solution[[ord]]$d[!substr(solution[[ord]]$vsnam, 
+                ld <- length(solution[[ord]]$d[!substr(solution[[ord]]$vsnam,
                   1, 1) == "*"])
                 if (length(nbvs) == 1) {
                   nbvs <- min(max(5, nbvs), ld)
                   nbvs <- 1:nbvs
                 }
-                scre <- 100 * ((solution[[ord]]$d[!substr(solution[[ord]]$vsnam, 
+                scre <- 100 * ((solution[[ord]]$d[!substr(solution[[ord]]$vsnam,
                   1, 1) == "*"])^2)/divv
                 scre <- (sort(scre[nbvs]))
                 scre <- scre[length(scre):1]
                 nbvs <- nbvs[1:length(scre)]
-                plot(nbvs, scre, xlab = "Ordered ", ylab = "Squared Singular Values (%)", 
+                plot(nbvs, scre, xlab = "Ordered ", ylab = "Squared Singular Values (%)",
                   xaxt = "n", ...)
                 axis(1, at = nbvs)
                 par(new = TRUE)
-                plot(nbvs, ylim = c(0, 100), cumsum(scre), axes = FALSE, 
-                  lwd = 2, lty = 1, type = "b", pch = "c", col = 3, 
+                plot(nbvs, ylim = c(0, 100), cumsum(scre), axes = FALSE,
+                  lwd = 2, lty = 1, type = "b", pch = "c", col = 3,
                   xlab = "", ylab = "")
-                axis(4, at = atpc <- seq(0, 100, 10), labels = formatC(atpc, 
+                axis(4, at = atpc <- seq(0, 100, 10), labels = formatC(atpc,
                   format = "fg"), col.axis = 3)
                 par(new = TRUE)
-                if (!is.null(RiskJack)) 
-                  RiskJack.plot(solution, nbvs = nbvs, mod = mod, 
-                    max = min(RiskJack + length(nbvs), ld), rescaled = TRUE, 
+                if (!is.null(RiskJack))
+                  RiskJack.plot(solution, nbvs = nbvs, mod = mod,
+                    max = min(RiskJack + length(nbvs), ld), rescaled = TRUE,
                     axes = FALSE, ann = FALSE, pch = "r")
                 par(new = FALSE)
             }
             if (ordered == FALSE) {
-                ld <- length(solution[[ord]]$d[!substr(solution[[ord]]$vsnam, 
+                ld <- length(solution[[ord]]$d[!substr(solution[[ord]]$vsnam,
                   1, 1) == "*"])
                 if (length(nbvs) == 1) {
                   nbvs <- min(max(5, nbvs), ld)
                   nbvs <- 1:nbvs
                 }
                 scre <- ((solution[[ord]]$d)^2)[nbvs]
-                plot(nbvs, scre, xlab = "Unordered with redundancy", 
+                plot(nbvs, scre, xlab = "Unordered with redundancy",
                   ylab = "Squared Singular Values", ...)
             }
         }
